@@ -36,13 +36,15 @@ class CollapseTransformer(TrackedContextTransformer):
     def visit_Subscript(self, node):
         return self.resolve_literal(self.generic_visit(node))
 
-    def _visit_AssignSubscriptTarget(self, target):
+    def _visit_Assign_withSubscriptLHS(self, target):
         def resolve_attr_of_slice(attr):
             old_val = getattr(target.slice, attr)
             if old_val is None:
                 return
-            new_val = self.resolve_literal(self.generic_visit(old_val))
+            new_val = self.visit(old_val)
             setattr(target.slice, attr, new_val)
+
+        target.value = self.generic_visit(target.value)
         if isinstance(target.slice, ast.Index):
             resolve_attr_of_slice('value')
         elif isinstance(target.slice, ast.Slice):
@@ -55,12 +57,12 @@ class CollapseTransformer(TrackedContextTransformer):
     def visit_Assign(self, node):
         for it, target in enumerate(node.targets):
             if isinstance(target, ast.Subscript):
-                self._visit_AssignSubscriptTarget(target)
+                self._visit_Assign_withSubscriptLHS(target)
         return super().visit_Assign(node)
 
     def visit_AugAssign(self, node):
         if isinstance(node.target, ast.Subscript):
-            self._visit_AssignSubscriptTarget(node.target)
+            self._visit_Assign_withSubscriptLHS(node.target)
         return super().visit_AugAssign(node)
 
     def visit_Call(self, node):
